Misc spelling and typos

Francois Gouget fgouget at free.fr
Thu May 8 20:14:21 CDT 2003


Changelog:

   Fix miscellaneous spelling errors and typos.


Index: dlls/avifil32/acmstream.c
===================================================================
RCS file: /home/wine/wine/dlls/avifil32/acmstream.c,v
retrieving revision 1.4
diff -u -r1.4 acmstream.c
--- dlls/avifil32/acmstream.c	10 Apr 2003 18:17:36 -0000	1.4
+++ dlls/avifil32/acmstream.c	9 May 2003 00:55:26 -0000
@@ -629,7 +629,7 @@
   if ((This->sInfo.dwCaps & AVIFILECAPS_CANWRITE) == 0)
     return AVIERR_READONLY;

-  /* A compressor is also neccessary */
+  /* A compressor is also necessary */
   if (This->has == NULL)
     return AVIERR_NOCOMPRESSOR;

Index: dlls/avifil32/api.c
===================================================================
RCS file: /home/wine/wine/dlls/avifil32/api.c,v
retrieving revision 1.14
diff -u -r1.14 api.c
--- dlls/avifil32/api.c	3 Jan 2003 19:12:56 -0000	1.14
+++ dlls/avifil32/api.c	9 May 2003 00:55:27 -0000
@@ -1047,7 +1047,7 @@
   if (cbFilter > size) {
     int i;

-    /* replace '@' with \000 to seperate description of filter */
+    /* replace '@' with \000 to separate description of filter */
     for (i = 0; i < size && szAllFiles[i] != 0; i++) {
       if (szAllFiles[i] == '@') {
 	szAllFiles[i] = 0;
Index: dlls/avifil32/avifile.c
===================================================================
RCS file: /home/wine/wine/dlls/avifil32/avifile.c,v
retrieving revision 1.32
diff -u -r1.32 avifile.c
--- dlls/avifil32/avifile.c	10 Apr 2003 18:17:36 -0000	1.32
+++ dlls/avifil32/avifile.c	9 May 2003 00:55:28 -0000
@@ -1372,7 +1372,7 @@
   This->idxFrames[This->lLastFrame].dwChunkOffset = offset;
   This->idxFrames[This->lLastFrame].dwChunkLength = size;

-  /* update AVISTREAMINFO structure if neccessary */
+  /* update AVISTREAMINFO structure if necessary */
   if (This->sInfo.dwLength < This->lLastFrame)
     This->sInfo.dwLength = This->lLastFrame;

@@ -2046,7 +2046,7 @@
   if (mmioAscend(This->hmmio, &ck, 0) != S_OK)
     return AVIERR_FILEWRITE;

-  /* write the headers of each stream into a seperate streamheader list */
+  /* write the headers of each stream into a separate streamheader list */
   for (nStream = 0; nStream < This->fInfo.dwStreams; nStream++) {
     AVIStreamHeader strHdr;

@@ -2087,7 +2087,7 @@
     if (mmioAscend(This->hmmio, &ck, 0) != S_OK)
       return AVIERR_FILEWRITE;

-    /* ... the hopefull ever present streamformat ... */
+    /* ... the hopefully ever present streamformat ... */
     ck.ckid   = ckidSTREAMFORMAT;
     ck.cksize = pStream->cbFormat;
     if (mmioCreateChunk(This->hmmio, &ck, 0) != S_OK)
Index: dlls/ddraw/d3ddevice/mesa.c
===================================================================
RCS file: /home/wine/wine/dlls/ddraw/d3ddevice/mesa.c,v
retrieving revision 1.92
diff -u -r1.92 mesa.c
--- dlls/ddraw/d3ddevice/mesa.c	4 May 2003 02:24:03 -0000	1.92
+++ dlls/ddraw/d3ddevice/mesa.c	9 May 2003 00:55:30 -0000
@@ -599,7 +599,7 @@
     } else if (dwLightStateType == D3DLIGHTSTATE_COLORMODEL /* 3 */) {
 	switch (dwLightState) {
 	    case D3DCOLOR_MONO:
-	       ERR("DDCOLOR_MONO should not happend!\n");
+	       ERR("DDCOLOR_MONO should not happen!\n");
 	       break;
 	    case D3DCOLOR_RGB:
 	       /* We are already in this mode */
Index: dlls/dplayx/name_server.c
===================================================================
RCS file: /home/wine/wine/dlls/dplayx/name_server.c,v
retrieving revision 1.13
diff -u -r1.13 name_server.c
--- dlls/dplayx/name_server.c	7 Jan 2003 20:36:29 -0000	1.13
+++ dlls/dplayx/name_server.c	9 May 2003 00:55:30 -0000
@@ -158,7 +158,7 @@

   lpCache->present = lpCacheNode;

-  /* Use this message as an oportunity to weed out any old sessions so
+  /* Use this message as an opportunity to weed out any old sessions so
    * that we don't enum them again
    */
   NS_PruneSessionCache( lpNSInfo );
@@ -236,7 +236,7 @@

   lpMsg = (LPDPMSG_ENUMSESSIONSREQUEST)(((BYTE*)data.lpMessage)+lpSpData->dwSPHeaderSize);

-  /* Setup EnumSession reqest message */
+  /* Setup EnumSession request message */
   lpMsg->envelope.dwMagic    = DPMSGMAGIC_DPLAYMSG;
   lpMsg->envelope.wCommandId = DPMSGCMD_ENUMSESSIONSREQUEST;
   lpMsg->envelope.wVersion   = DPMSGVER_DP6;
@@ -267,7 +267,7 @@

   if( lpCache == NULL )
   {
-    ERR( ": invalidate non existant cache\n" );
+    ERR( ": invalidate non existent cache\n" );
     return;
   }

@@ -362,7 +362,7 @@
       break;
     }

-    /* Deal with time in a wrap around safe manner - unsigned arithmatic.
+    /* Deal with time in a wrap around safe manner - unsigned arithmetic.
      * Check the difference in time */
     if( (dwPresentTime - (DPQ_FIRST(lpCache->first)->dwTime)) < dwPrunePeriod )
     {
Index: dlls/msvcrt/except.c
===================================================================
RCS file: /home/wine/wine/dlls/msvcrt/except.c,v
retrieving revision 1.23
diff -u -r1.23 except.c
--- dlls/msvcrt/except.c	12 Dec 2002 23:34:02 -0000	1.23
+++ dlls/msvcrt/except.c	9 May 2003 00:55:34 -0000
@@ -107,7 +107,7 @@
  *		_EH_prolog (MSVCRT.@)
  */
 #ifdef __i386__
-/* Provided for VC++ binary compatability only */
+/* Provided for VC++ binary compatibility only */
 __ASM_GLOBAL_FUNC(_EH_prolog,
                   "pushl $-1\n\t"
                   "pushl %eax\n\t"
Index: dlls/ntdll/rtlbitmap.c
===================================================================
RCS file: /home/wine/wine/dlls/ntdll/rtlbitmap.c,v
retrieving revision 1.5
diff -u -r1.5 rtlbitmap.c
--- dlls/ntdll/rtlbitmap.c	2 Apr 2003 01:23:44 -0000	1.5
+++ dlls/ntdll/rtlbitmap.c	9 May 2003 00:55:34 -0000
@@ -23,7 +23,7 @@
  *  but are also available to applications that need this functionality.
  *
  *  Bits are set LSB to MSB in each consecutive byte, making this implementation
- *  binary compatable with Win32.
+ *  binary compatible with Win32.
  *
  *  Note that to avoid unexpected behaviour, the size of a bitmap should be set
  *  to a multiple of 32.
Index: dlls/ole32/compobj_private.h
===================================================================
RCS file: /home/wine/wine/dlls/ole32/compobj_private.h,v
retrieving revision 1.6
diff -u -r1.6 compobj_private.h
--- dlls/ole32/compobj_private.h	11 Mar 2003 01:45:39 -0000	1.6
+++ dlls/ole32/compobj_private.h	9 May 2003 00:55:35 -0000
@@ -45,7 +45,7 @@

 #define PIPEPREF "\\\\.\\pipe\\"
 #define OLESTUBMGR PIPEPREF"WINE_OLE_StubMgr"
-/* Standard Marshaling definitions */
+/* Standard Marshalling definitions */
 typedef struct _wine_marshal_id {
     DWORD	processid;
     DWORD	objectid;	/* unique value corresp. IUnknown of object */
Index: dlls/ole32/ftmarshal.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/ftmarshal.c,v
retrieving revision 1.4
diff -u -r1.4 ftmarshal.c
--- dlls/ole32/ftmarshal.c	10 Apr 2003 18:17:35 -0000	1.4
+++ dlls/ole32/ftmarshal.c	9 May 2003 00:55:35 -0000
@@ -1,5 +1,5 @@
 /*
- *	free threaded marshaler
+ *	free threaded marshaller
  *
  *  Copyright 2002  Juergen Schmied
  *
@@ -141,14 +141,14 @@

     FIXME ("(), stub!\n");

-    /* if the marshaling happends inside the same process the interface pointer is
-       copied between the appartments */
+    /* if the marshalling happens inside the same process the interface pointer is
+       copied between the apartments */
     if (dwDestContext == MSHCTX_INPROC || dwDestContext == MSHCTX_CROSSCTX) {
 	*pSize = sizeof (This);
 	return S_OK;
     }

-    /* use the standard marshaler to handle all other cases */
+    /* use the standard marshaller to handle all other cases */
     CoGetStandardMarshal (riid, pv, dwDestContext, pvDestContext, mshlflags, &pMarshal);
     hres = IMarshal_GetMarshalSizeMax (pMarshal, riid, pv, dwDestContext, pvDestContext, mshlflags, pSize);
     IMarshal_Release (pMarshal);
@@ -168,8 +168,8 @@

     FIXME ("(), stub!\n");

-    /* if the marshaling happends inside the same process the interface pointer is
-       copied between the appartments */
+    /* if the marshalling happens inside the same process the interface pointer is
+       copied between the apartments */
     if (dwDestContext == MSHCTX_INPROC || dwDestContext == MSHCTX_CROSSCTX) {
 	return IStream_Write (pStm, This, sizeof (This), 0);
     }
Index: dlls/ole32/marshal.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/marshal.c,v
retrieving revision 1.8
diff -u -r1.8 marshal.c
--- dlls/ole32/marshal.c	11 Mar 2003 01:45:38 -0000	1.8
+++ dlls/ole32/marshal.c	9 May 2003 00:55:36 -0000
@@ -1,5 +1,5 @@
 /*
- *	Marshaling library
+ *	Marshalling library
  *
  *  Copyright 2002  Marcus Meissner
  *
@@ -45,7 +45,7 @@

 extern const CLSID CLSID_DfMarshal;

-/* Marshaling just passes a unique identifier to the remote client,
+/* Marshalling just passes a unique identifier to the remote client,
  * that makes it possible to find the passed interface again.
  *
  * So basically we need a set of values that make it unique.
@@ -350,9 +350,9 @@
 /***********************************************************************
  *		CoGetStandardMarshal	[OLE32.23]
  *
- * When the COM library in the client process receives a marshaled
+ * When the COM library in the client process receives a marshalled
  * interface pointer, it looks for a CLSID to be used in creating a proxy
- * for the purposes of unmarshaling the packet. If the packet does not
+ * for the purposes of unmarshalling the packet. If the packet does not
  * contain a CLSID for the proxy, COM calls CoGetStandardMarshal, passing a
  * NULL pUnk value.
  * This function creates a standard proxy in the client process and returns
Index: dlls/ole32/oleproxy.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/oleproxy.c,v
retrieving revision 1.6
diff -u -r1.6 oleproxy.c
--- dlls/ole32/oleproxy.c	7 Jan 2003 20:36:27 -0000	1.6
+++ dlls/ole32/oleproxy.c	9 May 2003 00:55:36 -0000
@@ -252,7 +252,7 @@
 }

 /* Since we create proxy buffers and classfactory in a pair, there is
- * no need for 2 seperate structs. Just put them in one, but remember
+ * no need for 2 separate structs. Just put them in one, but remember
  * the refcount.
  */
 typedef struct _CFProxy {
@@ -313,7 +313,7 @@
 	IClassFactory_AddRef(iface);
 	return S_OK;
     }
-    if (IsEqualIID(riid,&IID_IMarshal)) /* just to avoid debugoutput */
+    if (IsEqualIID(riid,&IID_IMarshal)) /* just to avoid debug output */
 	return E_NOINTERFACE;
     FIXME("Unhandled interface: %s\n",debugstr_guid(riid));
     return E_NOINTERFACE;
@@ -371,7 +371,7 @@
     if (!msg.cbBuffer) /* interface not found on remote */
 	return srstatus;

-    /* We got back: [Marshaled Interface data] */
+    /* We got back: [Marshalled Interface data] */
     TRACE("got %ld bytes data.\n",msg.cbBuffer);
     hGlobal = GlobalAlloc(GMEM_MOVEABLE|GMEM_NODISCARD|GMEM_SHARE,msg.cbBuffer);
     memcpy(GlobalLock(hGlobal),msg.Buffer,msg.cbBuffer);
Index: dlls/ole32/storage32.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/storage32.c,v
retrieving revision 1.37
diff -u -r1.37 storage32.c
--- dlls/ole32/storage32.c	10 Apr 2003 18:17:35 -0000	1.37
+++ dlls/ole32/storage32.c	9 May 2003 00:55:38 -0000
@@ -6502,7 +6502,7 @@
 /*************************************************************************
  * OLECONVERT_CreateOleStream [Internal]
  *
- * Creates the "\001OLE" stream in the IStorage if neccessary.
+ * Creates the "\001OLE" stream in the IStorage if necessary.
  *
  * PARAMS
  *     pStorage     [I] Dest storage to create the stream in
Index: dlls/oleaut32/tmarshal.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/tmarshal.c,v
retrieving revision 1.16
diff -u -r1.16 tmarshal.c
--- dlls/oleaut32/tmarshal.c	17 Apr 2003 02:20:52 -0000	1.16
+++ dlls/oleaut32/tmarshal.c	9 May 2003 00:55:40 -0000
@@ -117,7 +117,7 @@
     if (hres) { FIXME("Failed Seek %lx\n",hres); return hres;}
     hres = CoUnmarshalInterface(pStm,riid,(LPVOID*)pUnk);
     if (hres) {
-	FIXME("Marshaling interface %s failed with %lx\n",debugstr_guid(riid),hres);
+	FIXME("Marshalling interface %s failed with %lx\n",debugstr_guid(riid),hres);
 	return hres;
     }
     IStream_Release(pStm);
@@ -154,7 +154,7 @@
     hres = CoMarshalInterface(pStm,riid,newiface,0,NULL,0);
     IUnknown_Release(newiface);
     if (hres) {
-	FIXME("Marshaling interface %s failed with %lx\n",
+	FIXME("Marshalling interface %s failed with %lx\n",
 		debugstr_guid(riid),hres
 	);
 	goto fail;
Index: dlls/oleaut32/typelib.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/typelib.c,v
retrieving revision 1.93
diff -u -r1.93 typelib.c
--- dlls/oleaut32/typelib.c	17 Apr 2003 02:20:52 -0000	1.93
+++ dlls/oleaut32/typelib.c	9 May 2003 00:55:42 -0000
@@ -4762,7 +4762,7 @@

 /* ITypeInfo::GetMops
  *
- * Retrieves marshaling information.
+ * Retrieves marshalling information.
  */
 static HRESULT WINAPI ITypeInfo_fnGetMops( ITypeInfo2 *iface, MEMBERID memid,
 				BSTR  *pBstrMops)
Index: dlls/oleaut32/usrmarshal.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/usrmarshal.c,v
retrieving revision 1.2
diff -u -r1.2 usrmarshal.c
--- dlls/oleaut32/usrmarshal.c	27 Apr 2003 00:40:47 -0000	1.2
+++ dlls/oleaut32/usrmarshal.c	9 May 2003 00:55:42 -0000
@@ -277,7 +277,7 @@
     break;
   }
   var->clSize = Pos - Buffer;
-  TRACE("marshaled size=%ld\n", var->clSize);
+  TRACE("marshalled size=%ld\n", var->clSize);
   return Pos;
 }

@@ -290,7 +290,7 @@
   TRACE("(%lx,%p,%p)\n", *pFlags, Buffer, pvar);
   VariantInit(pvar);
   pvar->n1.n2.vt = var->rpcReserved;
-  TRACE("marshaled: clSize=%ld, vt=%04x\n", var->clSize, var->vt);
+  TRACE("marshalled: clSize=%ld, vt=%04x\n", var->clSize, var->vt);
   TRACE("vt=%04x\n", V_VT(pvar));
   TRACE("reserved: %d, %d, %d\n", var->wReserved1, var->wReserved2, var->wReserved3);
   TRACE("val: %ld\n", var->u.lVal);
Index: dlls/rpcrt4/rpcrt4_main.c
===================================================================
RCS file: /home/wine/wine/dlls/rpcrt4/rpcrt4_main.c,v
retrieving revision 1.42
diff -u -r1.42 rpcrt4_main.c
--- dlls/rpcrt4/rpcrt4_main.c	28 Mar 2003 00:36:13 -0000	1.42
+++ dlls/rpcrt4/rpcrt4_main.c	9 May 2003 00:55:43 -0000
@@ -22,7 +22,7 @@
  * - widl is like MIDL for wine.  For wine to be a useful RPC platform, quite
  *   a bit of work needs to be done here.  widl currently doesn't generate stubs
  *   for RPC invocation -- it will need to; this is tricky because the MIDL compiler
- *   does some really wierd stuff.  Then again, we don't neccesarily have to
+ *   does some really weird stuff.  Then again, we don't necessarily have to
  *   make widl work like MIDL, so it could be worse.  Lately Ove has been working on
  *   some widl enhancements.
  *
Index: dlls/rpcrt4/rpcss_np_client.c
===================================================================
RCS file: /home/wine/wine/dlls/rpcrt4/rpcss_np_client.c,v
retrieving revision 1.2
diff -u -r1.2 rpcss_np_client.c
--- dlls/rpcrt4/rpcss_np_client.c	14 Jan 2003 23:43:42 -0000	1.2
+++ dlls/rpcrt4/rpcss_np_client.c	9 May 2003 00:55:43 -0000
@@ -118,7 +118,7 @@
     return FALSE;
   }

-  /* process the vardata payload if neccesary */
+  /* process the vardata payload if necessary */
   vardata_payload_msg.message_type = RPCSS_NP_MESSAGE_TYPEID_VARDATAPAYLOADMSG;
   vardata_payload_msg.vardata_payload_size = 0; /* meaningless */
   for ( payload_offset = 0; payload_offset < msg->vardata_payload_size;
Index: dlls/setupapi/setupapi.rc
===================================================================
RCS file: /home/wine/wine/dlls/setupapi/setupapi.rc,v
retrieving revision 1.3
diff -u -r1.3 setupapi.rc
--- dlls/setupapi/setupapi.rc	1 Jun 2002 02:55:50 -0000	1.3
+++ dlls/setupapi/setupapi.rc	9 May 2003 00:55:43 -0000
@@ -25,7 +25,7 @@

 /*--------------------- FIXME --------------------------
  *
- * These must be seperated into the language files
+ * These must be separated into the language files
  * and translated. The language 0,0 is a hack to get it
  * loaded properly for all languages by pretending that
  * they are neutral.
Index: dlls/shell32/shres.rc
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shres.rc,v
retrieving revision 1.27
diff -u -r1.27 shres.rc
--- dlls/shell32/shres.rc	19 Dec 2002 04:11:22 -0000	1.27
+++ dlls/shell32/shres.rc	9 May 2003 00:55:43 -0000
@@ -26,7 +26,7 @@

 /*--------------------- FIXME --------------------------
  *
- * These must be seperated into the language files
+ * These must be separated into the language files
  * and translated. The language 0,0 is a hack to get it
  * loaded properly for all languages by pretending that
  * they are neutral.
Index: dlls/shlwapi/path.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/path.c,v
retrieving revision 1.31
diff -u -r1.31 path.c
--- dlls/shlwapi/path.c	2 Apr 2003 01:23:44 -0000	1.31
+++ dlls/shlwapi/path.c	9 May 2003 00:55:45 -0000
@@ -682,7 +682,7 @@
 /*************************************************************************
  * PathRemoveArgsA	[SHLWAPI.@]
  *
- * Strip space seperated arguments from a path.
+ * Strip space separated arguments from a path.
  *
  * PARAMS
  *  lpszPath [I] Path to remove arguments from
@@ -1778,7 +1778,7 @@
  * NOTES
  *  Multiple search masks may be given if they are seperated by ";". The
  *  pattern "*.*" is treated specially in that it matches all paths (for
- *  backwards compatability with DOS).
+ *  backwards compatibility with DOS).
  */
 BOOL WINAPI PathMatchSpecA(LPCSTR lpszPath, LPCSTR lpszMask)
 {
@@ -2601,7 +2601,7 @@
   } while (1);

   if (iLen == 2)
-    iLen++; /* Feature/Bug compatable with Win32 */
+    iLen++; /* Feature/Bug compatible with Win32 */

   if (iLen && achPath)
   {
@@ -2656,7 +2656,7 @@
   } while (1);

   if (iLen == 2)
-    iLen++; /* Feature/Bug compatable with Win32 */
+    iLen++; /* Feature/Bug compatible with Win32 */

   if (iLen && achPath)
   {
@@ -2871,7 +2871,7 @@
          flags |= GCT_SHORTCHAR; /* All these are valid for DOS */
      }
      else
-       flags |= GCT_SHORTCHAR; /* Bug compatable with win32 */
+       flags |= GCT_SHORTCHAR; /* Bug compatible with win32 */
      flags |= GCT_LFNCHAR; /* Valid for long file names */
   }
   return flags;
Index: documentation/documentation.sgml
===================================================================
RCS file: /home/wine/wine/documentation/documentation.sgml,v
retrieving revision 1.9
diff -u -r1.9 documentation.sgml
--- documentation/documentation.sgml	21 Apr 2003 22:43:16 -0000	1.9
+++ documentation/documentation.sgml	9 May 2003 00:55:51 -0000
@@ -148,7 +148,7 @@
           <listItem><para>
           Additional notes such as interaction with other parts of the system, differences
           between Wines implementation and Win32s, errors in MSDN documentation,
-          undocumented cases and bugs that Wine corrects or is compatable with.
+          undocumented cases and bugs that Wine corrects or is compatible with.
           </para></listitem>

           </itemizedlist>
@@ -340,7 +340,7 @@

           <listItem><para>
           <command>BUGS</command>. Any bugs in the function that exist 'by design', i.e.
-          those that will not be fixed or exist for compatability with Windows.
+          those that will not be fixed or exist for compatibility with Windows.
           </para></listitem>

           <listItem><para>
Index: documentation/porting.sgml
===================================================================
RCS file: /home/wine/wine/documentation/porting.sgml,v
retrieving revision 1.5
diff -u -r1.5 porting.sgml
--- documentation/porting.sgml	19 Apr 2003 02:50:57 -0000	1.5
+++ documentation/porting.sgml	9 May 2003 00:55:53 -0000
@@ -65,13 +65,13 @@

         <itemizedlist>
           <listitem>
-            <para>existance of a header file</para>
+            <para>existence of a header file</para>
           </listitem>
           <listitem>
-            <para>existance of a library function</para>
+            <para>existence of a library function</para>
           </listitem>
           <listitem>
-            <para>existance of libraries</para>
+            <para>existence of libraries</para>
           </listitem>
           <listitem>
             <para>bugs in header files, library functions, the compiler, ...</para>
Index: documentation/winelib-porting.sgml
===================================================================
RCS file: /home/wine/wine/documentation/winelib-porting.sgml,v
retrieving revision 1.5
diff -u -r1.5 winelib-porting.sgml
--- documentation/winelib-porting.sgml	19 Apr 2003 02:50:57 -0000	1.5
+++ documentation/winelib-porting.sgml	9 May 2003 00:55:53 -0000
@@ -222,7 +222,7 @@
       <para>
         In order to avoid warnings in C (and potential errors in C++)
         from not having prototypes, you may need to use a set of MS
-        compatable header files. These are scheduled for inclusion
+        compatible header files. These are scheduled for inclusion
         into Wine but at the time of writing are not available. Until
         they are, you can try prototyping the functions you need, or
         just live with the warnings.
Index: graphics/painting.c
===================================================================
RCS file: /home/wine/wine/graphics/painting.c,v
retrieving revision 1.56
diff -u -r1.56 painting.c
--- graphics/painting.c	11 Apr 2003 00:37:17 -0000	1.56
+++ graphics/painting.c	9 May 2003 00:55:54 -0000
@@ -886,12 +886,12 @@
  /*
   * some macro definitions for bezier drawing
   *
-  * to avoid trucation errors the coordinates are
+  * to avoid truncation errors the coordinates are
   * shifted upwards. When used in drawing they are
   * shifted down again, including correct rounding
-  * and avoiding floating point arithmatic
+  * and avoiding floating point arithmetic
   * 4 bits should allow 27 bits coordinates which I saw
-  * somewere in the win32 doc's
+  * somewhere in the win32 doc's
   *
   */

Index: memory/global.c
===================================================================
RCS file: /home/wine/wine/memory/global.c,v
retrieving revision 1.80
diff -u -r1.80 global.c
--- memory/global.c	2 Apr 2003 01:23:43 -0000	1.80
+++ memory/global.c	9 May 2003 00:55:57 -0000
@@ -1060,7 +1060,7 @@
 #define POINTER_TO_HANDLE(p) (*(((HGLOBAL *)(p))-2))
 #define ISHANDLE(h)          (((DWORD)(h)&2)!=0)
 #define ISPOINTER(h)         (((DWORD)(h)&2)==0)
-/* allign the storage needed for the HGLOBAL on an 8byte boundary thus
+/* align the storage needed for the HGLOBAL on an 8byte boundary thus
  * GlobalAlloc/GlobalReAlloc'ing with GMEM_MOVEABLE of memory with
  * size = 8*k, where k=1,2,3,... alloc's exactly the given size.
  * The Minolta DiMAGE Image Viewer heavily relies on this, corrupting
Index: msdos/ppdev.c
===================================================================
RCS file: /home/wine/wine/msdos/ppdev.c,v
retrieving revision 1.8
diff -u -r1.8 ppdev.c
--- msdos/ppdev.c	13 Sep 2002 17:47:44 -0000	1.8
+++ msdos/ppdev.c	9 May 2003 00:55:57 -0000
@@ -139,7 +139,7 @@
 	if (ioctl (fd,PPCLAIM,0))
 	  {
 	    ERR("PPCLAIM rejected %s\n",buffer);
-	    ERR("Perhaps the device is already in use or non-existant\n");
+	    ERR("Perhaps the device is already in use or non-existent\n");
 	    continue;
 	  }
 	if (nports > 0)
@@ -168,7 +168,7 @@
 	if (ioctl (fd,PPRELEASE,0))
 	  {
 	    ERR("PPRELEASE rejected %s\n",buffer);
-	    ERR("Perhaps the device is already in use or non-existant\n");
+	    ERR("Perhaps the device is already in use or non-existent\n");
 	    continue;
 	  }
 	PPDeviceList[nports].devicename = malloc(sizeof(buffer)+1);
Index: programs/rpcss/rpcss_main.c
===================================================================
RCS file: /home/wine/wine/programs/rpcss/rpcss_main.c,v
retrieving revision 1.3
diff -u -r1.3 rpcss_main.c
--- programs/rpcss/rpcss_main.c	14 Jan 2003 23:43:41 -0000	1.3
+++ programs/rpcss/rpcss_main.c	9 May 2003 00:55:57 -0000
@@ -43,8 +43,8 @@
  *   o Wine's named pipes (in general) may not interoperate with those of
  *     Windows yet (?)
  *
- *   o There is a looming problem regarding listening on priveleged
- *     ports.  We will need to be able to coexist with SAMBA, and able
+ *   o There is a looming problem regarding listening on privileged
+ *     ports.  We will need to be able to coexist with SAMBA, and be able
  *     to function without running winelib code as root.  This may
  *     take some doing, including significant reconceptualization of the
  *     role of rpcss.exe in wine.
@@ -79,7 +79,7 @@
 {
   /* FIXME: this max ensures that no caller will decrease our wait time,
      but could have other bad results.  fix: Store "next_max_lazy_timeout"
-     and install it as neccesary next time we "do work"? */
+     and install it as necessary next time we "do work"? */
   max_lazy_timeout = max(RPCSS_GetLazyTimeRemaining(), mlt);
 }

Index: tools/c2man.pl
===================================================================
RCS file: /home/wine/wine/tools/c2man.pl,v
retrieving revision 1.7
diff -u -r1.7 c2man.pl
--- tools/c2man.pl	16 Apr 2003 23:09:28 -0000	1.7
+++ tools/c2man.pl	9 May 2003 00:55:58 -0000
@@ -759,7 +759,7 @@
   $prototype =~ s/ *\* */\*/g;     # Strip space around pointers
   $prototype =~ s/ *\, */\,/g;     # Strip space around commas
   $prototype =~ s/^(void|VOID)$//; # If void, leave blank
-  $prototype =~ s/\*([A-Za-z_])/\* $1/g; # Seperate pointers from parameter name
+  $prototype =~ s/\*([A-Za-z_])/\* $1/g; # Separate pointers from parameter name
   @{$comment->{PROTOTYPE}} = split ( /,/ ,$prototype);

   # FIXME: If we have no parameters, make sure we have a PARAMS: None. section




Index: dlls/kernel/tests/path.c
===================================================================
RCS file: /home/wine/wine/dlls/kernel/tests/path.c,v
retrieving revision 1.14
diff -u -r1.14 path.c
--- dlls/kernel/tests/path.c	14 Jan 2003 23:43:42 -0000	1.14
+++ dlls/kernel/tests/path.c	9 May 2003 00:55:33 -0000
@@ -32,9 +32,9 @@
 #define SHORTDIR "shortdir"
 #define LONGDIR "Long Directory"
 #define NONFILE_SHORT "noexist.pth"
-#define NONFILE_LONG "Non Existant File"
+#define NONFILE_LONG "Non Existent File"
 #define NONDIR_SHORT "notadir"
-#define NONDIR_LONG "Non Existant Directory"
+#define NONDIR_LONG "Non Existent Directory"

 #define NOT_A_VALID_DRIVE '@'

@@ -198,7 +198,7 @@
   }
 /* Check that we didn't find a trailing '\\' or multiple '.' */
   ok(!error,"Illegal file found in 8.3 path '%s'",path);
-/* Seperate dir, root, and extension */
+/* Separate dir, root, and extension */
   if(ext!=len) lstrcpyA(three,path+ext+1); else lstrcpyA(three,"");
   if(fil!=len) {
     lstrcpynA(eight,path+fil+1,ext-fil);
@@ -228,7 +228,7 @@
    characters in the filename.
      'valid' indicates whether this would be an allowed filename
      'todo' indictaes that wine doesn't get this right yet.
-   NOTE: We always call this routine with a non-existant filename, so
+   NOTE: We always call this routine with a non-existent filename, so
          Get(Short|Long)PathNameA should never pass, but GetFullPathNameA
          should.
 */
@@ -438,10 +438,10 @@
    so why check it again.
 */
   SetCurrentDirectoryA(newdir);
 /* Check that SetCurrentDirectory fails when a non-existant dir is specified */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_SHORT);
   test_setdir(newdir,tmpstr,NULL,0,"check 3");
 /* Check that SetCurrentDirectory fails for a non-existant lond directory */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_LONG);
   test_setdir(newdir,tmpstr,NULL,0,"check 4");
 /* Check that SetCurrentDirectory passes with a long directory */
@@ -653,6 +653,6 @@
   test_ValidPathA(curdir,"",tmpstr,tmpstr1,NULL,"test13");
   sprintf(tmpstr,"%s\\",LONGDIR);
   test_ValidPathA(curdir,"",tmpstr,tmpstr1,NULL,"test14");
-/* Non-existant directories */
+/* Non-existent directories */
   sprintf(tmpstr,"%s\\",NONDIR_SHORT);
   test_ValidPathA(curdir,"",tmpstr,tmpstr1,&passfail,"test15");
@@ -438,10 +438,10 @@
 */
   SetCurrentDirectoryA(newdir);
-/* Check that SetCurrentDirectory fails when a non-existant dir is specified */
+/* Check that SetCurrentDirectory fails when a non-existent dir is specified */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_SHORT);
   test_setdir(newdir,tmpstr,NULL,0,"check 3");
@@ -438,10 +438,10 @@
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_SHORT);
   test_setdir(newdir,tmpstr,NULL,0,"check 3");
-/* Check that SetCurrentDirectory fails for a non-existant lond directory */
+/* Check that SetCurrentDirectory fails for a non-existent lond directory */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_LONG);
   test_setdir(newdir,tmpstr,NULL,0,"check 4");
Index: dlls/ole32/compobj.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/compobj.c,v
retrieving revision 1.73
diff -u -r1.73 compobj.c
--- dlls/ole32/compobj.c	11 Mar 2003 01:45:39 -0000	1.73
+++ dlls/ole32/compobj.c	9 May 2003 00:55:35 -0000
@@ -63,7 +63,7 @@
 static void* StdGlobalInterfaceTableInstance;

 /*****************************************************************************
  * Appartment management stuff
  *
  * NOTE:
  *  per Thread values are stored in the TEB on offset 0xF80
@@ -75,22 +75,22 @@
 typedef struct {
         unsigned char		threadingModell;	/* we use the COINIT flags */
         unsigned long		threadID;
-	long			AppartmentLockCount;
-} OleAppartmentData;
+	long			ApartmentLockCount;
+} OleApartmentData;

 typedef struct {
-	OleAppartmentData 	*AppartmentData;
+	OleApartmentData 	*ApartmentData;
 } OleThreadData;

 /* not jet used
-static CRITICAL_SECTION csAppartmentData = CRITICAL_SECTION_INIT("csAppartmentData");
+static CRITICAL_SECTION csApartmentData = CRITICAL_SECTION_INIT("csApartmentData");
 */
 /*
  * the first STA created in a process is the main STA
  */

 /* not jet used
-static OleAppartmentData * mainSTA;
+static OleApartmentData * mainSTA;
 */

 /*
@@ -98,7 +98,7 @@
  */

 /* not jet used
-static OleAppartmentData * processMTA;
+static OleApartmentData * processMTA;
 */
@@ -63,7 +63,7 @@

 /*****************************************************************************
- * Appartment management stuff
+ * Apartment management stuff
  *
  * NOTE:


-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
                         "Utilisateur" (nom commun) :
        Mot utilisé par les informaticiens en lieu et place d'"idiot".





More information about the wine-patches mailing list